@@ -15,6 +15,7 @@ Usage::
         ListConfigurationsPaginator,
         ListKafkaVersionsPaginator,
         ListNodesPaginator,
+        ListScramSecretsPaginator,
     )
 
     client: KafkaClient = boto3.client("kafka")
@@ -25,6 +26,7 @@ Usage::
     list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
     list_kafka_versions_paginator: ListKafkaVersionsPaginator = client.get_paginator("list_kafka_versions")
     list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
+    list_scram_secrets_paginator: ListScramSecretsPaginator = client.get_paginator("list_scram_secrets")
     ```
 """
 from typing import Iterator
@@ -38,6 +40,7 @@ from mypy_boto3_kafka.type_defs import (
     ListConfigurationsResponseTypeDef,
     ListKafkaVersionsResponseTypeDef,
     ListNodesResponseTypeDef,
+    ListScramSecretsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -48,82 +51,96 @@ __all__ = (
     "ListConfigurationsPaginator",
     "ListKafkaVersionsPaginator",
     "ListNodesPaginator",
+    "ListScramSecretsPaginator",
 )
 
 
 class ListClusterOperationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListClusterOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+    [Paginator.ListClusterOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
     """
 
     def paginate(
         self, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListClusterOperationsResponseTypeDef]:
         """
-        [ListClusterOperations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
+        [ListClusterOperations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
         """
 
 
 class ListClustersPaginator(Boto3Paginator):
     """
-    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListClusters)
     """
 
     def paginate(
         self, ClusterNameFilter: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListClustersResponseTypeDef]:
         """
-        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
+        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
         """
 
 
 class ListConfigurationRevisionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListConfigurationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+    [Paginator.ListConfigurationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
     """
 
     def paginate(
         self, Arn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListConfigurationRevisionsResponseTypeDef]:
         """
-        [ListConfigurationRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
+        [ListConfigurationRevisions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
         """
 
 
 class ListConfigurationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+    [Paginator.ListConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListConfigurationsResponseTypeDef]:
         """
-        [ListConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
+        [ListConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
         """
 
 
 class ListKafkaVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListKafkaVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+    [Paginator.ListKafkaVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListKafkaVersionsResponseTypeDef]:
         """
-        [ListKafkaVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
+        [ListKafkaVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
         """
 
 
 class ListNodesPaginator(Boto3Paginator):
     """
-    [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+    [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListNodes)
     """
 
     def paginate(
         self, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListNodesResponseTypeDef]:
         """
-        [ListNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.61/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
+        [ListNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
+        """
+
+
+class ListScramSecretsPaginator(Boto3Paginator):
+    """
+    [Paginator.ListScramSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+    """
+
+    def paginate(
+        self, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> Iterator[ListScramSecretsResponseTypeDef]:
+        """
+        [ListScramSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
         """
